import greenfoot.*;

/**
 * a world to demo my GQActor superclass; various bar controls are afforded the user
 * to alter the various states of the character
 */
public class GQWorld extends World
{
    private MseActBar gravBar, jumpBar, airBar, floorBar, speedBar, accelBar; // controls
    private Guy guy; // character
    
    public GQWorld()
    {
        super(800, 600, 1, false);
        
        /** the background */
        GreenfootImage bg = getBackground();
        bg.setColor(new Color(192, 192, 192));
        bg.fill();
        
        /** the character */
        guy = new Guy();
        int gravity = 40; // local fields would not be needed if it were not for the controls
        guy.setGravity(gravity);
        int jumpForce = 1000;
        guy.setJumping("up", jumpForce);
        int speed = 300, acceleration = 10;
        guy.setHorizontalMovement("left", "right", speed, acceleration);
        int platformDrag = 2;
        guy.setPlatformDrag(platformDrag);
        int airDrag = 0;
        guy.setDragForces(20, airDrag);
        addObject(guy, 50, 550);
        
        /** the platforms */
        for (int i=200; i<500; i+=50) addObject(new Wall(), i, 575);
        
        /** the controls */
        gravBar = new MseActBar("Gravity", "", gravity, 500);
        gravBar.setBreakValue(0);
        addObject(gravBar, 150, 20);
        
        jumpBar = new MseActBar("Jump Force", "", jumpForce, 2500);
        jumpBar.setBreakValue(0);
        addObject(jumpBar, 150, 40);

        airBar = new MseActBar("Air Drag", "", airDrag, 20);
        airBar.setBreakValue(0);
        addObject(airBar, 400, 20);

        floorBar = new MseActBar("Platform Drag", "", platformDrag, 200);
        floorBar.setBreakValue(0);
        floorBar.setMinimumValue(1);
        addObject(floorBar, 400, 40);

        speedBar = new MseActBar("Horizontal Speed", "max", speed, 500);
        speedBar.setBreakValue(0);
        addObject(speedBar, 650, 20);

        accelBar = new MseActBar("Acceleration", "", acceleration, 500);
        accelBar.setBreakValue(0);
        addObject(accelBar, 650, 40);
    }
    
    /** detects changes in control values */
    public void act()
    {
        if (gravBar.isChanged()) guy.setGravity(gravBar.getValue());
        if (jumpBar.isChanged()) guy.setJumpStrength(jumpBar.getValue());
        if (airBar.isChanged()) guy.setAirDrag(airBar.getValue());
        if (floorBar.isChanged()) guy.setPlatformDrag(floorBar.getValue());
        if (speedBar.isChanged()) guy.setMaximumSpeed(speedBar.getValue());
        if (accelBar.isChanged()) guy.setHorizontalAcceleration(accelBar.getValue());
    }
}